Commune class

Constructors

Commune({int? id, required int villeId, required String code, required String nom, required String villeCode})
Commune.fromMap(Map<String, dynamic> map)
factory

Properties

code String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int?
getter/setter pair
nom String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
villeCode String
getter/setter pair
villeId int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromList(List<Map<String, dynamic>> list) List<Commune>